import setuptools

setuptools.setup(
    name="AskGoogle",
    version="1.0.3",
    author="NathanTW0219",
    description="Automatically redirects to Google when an exception is thrown.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    license="MIT",
    packages=["askgoogle"],
    url="https://github.com/NathanTW0219/AskGoogle.py"
)
